(set-background "level2.png")
(set-skin "skin.png")
(set-bonus-time 80000)
(load "../utils.scm")
(block-rect 89 0 3 2 "dark-gray")
(block-rect 57 18 1 1 "dark-gray")
(block-rect 57 36 2 7 "dark-gray")
(block-rect 89 162 1 1 "dark-gray")
(block-rect 121 72 1 5 "dark-gray")
(block-rect 153 54 1 4 "dark-gray")
(block-rect 185 36 1 3 "dark-gray")
(block-rect 377 36 3 6 "dark-gray")
(block-rect 313 0 3 1 "dark-gray")
(block-rect 281 18 5 1 "dark-gray")
(block-rect 249 54 3 2 "dark-gray")
(block-rect 281 90 3 1 "dark-gray")
(block-rect 313 108 2 1 "dark-gray")
(block-rect 345 126 1 2 "dark-gray")
(block-rect 377 144 2 2 "dark-gray")
(block-rect 377 180 1 1 "dark-gray")


